Cleanup/wg init (#260)
* remove wg_init and wg_finalize from functional tests * Remove wg_init and wg_finalize from examples * deprecate wg_init/finalize * Updated docs * Typo in documentation --------- Co-authored-by: Yiltan <yiltan@amd.com>
This commit is contained in:
committed by
GitHub
parent
a1269e3db5
commit
6e7277b544
@@ -65,7 +65,6 @@ __global__ void allreduce_test(int *source, int *dest, size_t nelem,
|
||||
__shared__ rocshmem_ctx_t ctx;
|
||||
int64_t ctx_type = 0;
|
||||
|
||||
rocshmem_wg_init();
|
||||
rocshmem_wg_ctx_create(ctx_type, &ctx);
|
||||
int num_pes = rocshmem_ctx_n_pes(ctx);
|
||||
|
||||
@@ -75,7 +74,6 @@ __global__ void allreduce_test(int *source, int *dest, size_t nelem,
|
||||
__syncthreads();
|
||||
|
||||
rocshmem_wg_ctx_destroy(&ctx);
|
||||
rocshmem_wg_finalize();
|
||||
}
|
||||
|
||||
static void init_sendbuf (int *source, int nelem, int my_pe)
|
||||
|
||||
@@ -65,7 +65,6 @@ __global__ void alltoall_test(int *source, int *dest, size_t nelem,
|
||||
__shared__ rocshmem_ctx_t ctx;
|
||||
int64_t ctx_type = 0;
|
||||
|
||||
rocshmem_wg_init();
|
||||
rocshmem_wg_ctx_create(ctx_type, &ctx);
|
||||
int num_pes = rocshmem_ctx_n_pes(ctx);
|
||||
|
||||
@@ -75,7 +74,6 @@ __global__ void alltoall_test(int *source, int *dest, size_t nelem,
|
||||
__syncthreads();
|
||||
|
||||
rocshmem_wg_ctx_destroy(&ctx);
|
||||
rocshmem_wg_finalize();
|
||||
}
|
||||
|
||||
static void init_sendbuf (int *source, int nelem, int my_pe, int npes)
|
||||
|
||||
@@ -65,7 +65,6 @@ __global__ void broadcast_test(int *source, int *dest, size_t nelem,
|
||||
__shared__ rocshmem_ctx_t ctx;
|
||||
int64_t ctx_type = 0;
|
||||
|
||||
rocshmem_wg_init();
|
||||
rocshmem_wg_ctx_create(ctx_type, &ctx);
|
||||
int num_pes = rocshmem_ctx_n_pes(ctx);
|
||||
|
||||
@@ -75,7 +74,6 @@ __global__ void broadcast_test(int *source, int *dest, size_t nelem,
|
||||
__syncthreads();
|
||||
|
||||
rocshmem_wg_ctx_destroy(&ctx);
|
||||
rocshmem_wg_finalize();
|
||||
}
|
||||
|
||||
static void init_sendbuf(int *source, int nelem, int my_pe)
|
||||
|
||||
@@ -62,7 +62,6 @@ using namespace rocshmem;
|
||||
|
||||
__global__ void simple_getmem_test(int *src, int *dst, size_t nelem)
|
||||
{
|
||||
rocshmem_wg_init();
|
||||
|
||||
int threadId = blockIdx.x * blockDim.x + threadIdx.x;
|
||||
if (threadId == 0) {
|
||||
@@ -73,7 +72,6 @@ __global__ void simple_getmem_test(int *src, int *dst, size_t nelem)
|
||||
}
|
||||
|
||||
__syncthreads();
|
||||
rocshmem_wg_finalize();
|
||||
}
|
||||
|
||||
#define MAX_ELEM 256
|
||||
|
||||
@@ -63,7 +63,6 @@ using namespace rocshmem;
|
||||
__global__ void simple_put_signal_test(uint64_t *data, uint64_t *message, size_t nelem,
|
||||
uint64_t *sig_addr, int my_pe, int dst_pe)
|
||||
{
|
||||
rocshmem_wg_init();
|
||||
|
||||
int threadId = blockIdx.x * blockDim.x + threadIdx.x;
|
||||
|
||||
@@ -78,7 +77,6 @@ __global__ void simple_put_signal_test(uint64_t *data, uint64_t *message, size_t
|
||||
}
|
||||
|
||||
__syncthreads();
|
||||
rocshmem_wg_finalize();
|
||||
}
|
||||
|
||||
#define MAX_ELEM 256
|
||||
|
||||
Reference in New Issue
Block a user